@@ -11,6 +11,12 @@ legendre.polynomials <- function( n, normalized=FALSE )
 ###
    require( polynom )
    recurrences <- legendre.recurrences( n, normalized )
-   polynomials <- orthogonal.polynomials( recurrences )
+   if ( normalized ) {
+       h.0 <- 2
+       p.0 <- polynomial( c( 1 / sqrt( h.0 ) ) )
+       polynomials <- orthonormal.polynomials( recurrences, p.0 )
+   }
+   else
+       polynomials <- orthogonal.polynomials( recurrences )
    return( polynomials )
 }
